from setuptools import setup, find_packages

setup(
    name='miniatureOctoBatman',
    packages=find_packages(),
    namespace_packages=['miniatureOctoBatman'],
    version='0.1.1',
    description="Finn's collection of powerline modules",
    author='Finn Herzfeld',
    author_email='finn@finn.io',
    url='https://github.com/thefinn93/miniature-octo-batman'
    )
